#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hslua-module-path
version:              1.1.1
visibility:           public
id:                   hslua-module-path-1.1.1-Gu1GJYrROzD9FZiRzNPrXZ
key:                  hslua-module-path-1.1.1-Gu1GJYrROzD9FZiRzNPrXZ
license:              MIT
copyright:            © 2020-2024 Albert Krewinkel
maintainer:           Albert Krewinkel <tarleb@hslua.org>
author:               Albert Krewinkel
homepage:             https://hslua.org/
synopsis:             Lua module to work with file paths.
description:
    Lua module to work with file paths in a platform
    independent way.

category:             Foreign
abi:                  3e2e5dca5858014ce3fd01b9dce67bdc
exposed:              True
exposed-modules:      HsLua.Module.Path
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hslua-module-path-1.1.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hslua-module-path-1.1.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hslua-module-path-1.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-module-path
hs-libraries:         HShslua-module-path-1.1.1-Gu1GJYrROzD9FZiRzNPrXZ
depends:
    base-4.18.2.1 filepath-1.4.300.1
    hslua-core-2.3.2-EBhygEumBLfHnLecK1ksYW
    hslua-marshalling-2.3.2-7xliWOE0sVFFVygHBy4Gh0
    hslua-packaging-2.3.1-oCmNvOTG7fBils8ehoOYV text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-hslua-module-path/html/hslua-module-path.haddock

haddock-html:         /usr/share/doc/haskell-hslua-module-path/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

